@@ -9,7 +9,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = 
   qw(PRIVATE_PREFIX META_ATTR_NAME ON_SAVE_ATTR_NAME 
-     LOADED_FROM_DRIVER FLAG_DB_IS_PRIVATE
+     LOADED_FROM_DRIVER FLAG_DB_IS_PRIVATE MODIFIED_COLUMNS
      STATE_IN_DB STATE_LOADING STATE_SAVING STATE_CLONING);
 
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -19,6 +19,7 @@ use constant META_ATTR_NAME     => PRIVATE_PREFIX . '_meta';
 use constant ON_SAVE_ATTR_NAME  => PRIVATE_PREFIX . '_on_save';
 use constant LOADED_FROM_DRIVER => PRIVATE_PREFIX . '_loaded_from_driver';
 use constant FLAG_DB_IS_PRIVATE => PRIVATE_PREFIX . '_db_is_private';
+use constant MODIFIED_COLUMNS   => PRIVATE_PREFIX . '_modified_columns';
 use constant STATE_IN_DB        => PRIVATE_PREFIX . '_in_db';
 use constant STATE_LOADING      => PRIVATE_PREFIX . '_loading';
 use constant STATE_SAVING       => PRIVATE_PREFIX . '_saving';
