@@ -14,7 +14,9 @@ our $Debug;
 
 *Debug = \$Rose::DB::Object::Metadata::Debug;
 
-our $VERSION = '0.756';
+our $Sort_Columns_Alphabetically = 0; # hack for test suite
+
+our $VERSION = '0.757';
 
 use Rose::Class::MakeMethods::Generic
 (
@@ -358,6 +360,8 @@ sub auto_generate_foreign_keys
 
     FK: while(my $fk_info = $sth->fetchrow_hashref)
     {
+      $db->refine_dbi_foreign_key_info($fk_info, $self);
+
       CHECK_TABLE: # Make sure this column is from the right table
       {
         no warnings; # Allow undef coercion to empty string
@@ -381,8 +385,6 @@ sub auto_generate_foreign_keys
 
     FK_INFO: foreach my $fk_info (@fk_info)
     {
-      $db->refine_dbi_foreign_key_info($fk_info, $self);
-
       my $foreign_class = 
         $self->class_for(catalog => $fk_info->{'UK_TABLE_CAT'},
                          schema  => $fk_info->{'UK_TABLE_SCHEM'},
@@ -590,12 +592,12 @@ sub __by_rank
   my $pos1 = $a->ordinal_position;
   my $pos2 = $b->ordinal_position;
 
-  if(defined $pos1 && defined $pos2)
+  if(!$Sort_Columns_Alphabetically && defined $pos1 && defined $pos2)
   {
-    return $pos1 <=> $pos2 || lc $a->name cmp lc $b->name;
+    return $pos1 <=> $pos2 || lc($a->name) cmp lc($b->name);
   }
 
-  return lc $a->name cmp lc $b->name;
+  return lc($a->name) cmp lc($b->name);
 }
 
 sub perl_foreign_keys_definition
