@@ -6,7 +6,7 @@ use Carp;
 
 our $Debug = 0;
 
-our $VERSION = '0.62';
+our $VERSION = '0.754';
 
 use Rose::Class::MakeMethods::Set
 (
@@ -78,7 +78,7 @@ sub import
     {
       croak "Could not import method '$import_as' from $class into ",
             "$target_class - a method by that name already exists. ",
-            "Pass a '--force' argument to import() to override ",
+            "Pass a '-force' argument to import() to override ",
             "existing methods."
     }
 
@@ -291,6 +291,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
